module.exports = defineTest({
	description: 'respects getters created on functions'
});
